﻿/*   Nino Seisei 
 *  ©2012  Antonio Bolaños Arias.
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Seisei.Global
{
    public class Help
    {
        public static string Title = "Contenidos de  Nino Seisei";

        public static string Intro = "Introducción";
        public static string Intro_Text = "&nbsp;&nbsp;&nbsp;Nino Seisei es una herramienta libre bajo licencia GNU GPL v3 que permite generar código de aplicaciones de acceso a datos, donde, "
            + "a partir de lenguaje NINO el cual está basado en SQL, puede generar código en cualquier lenguaje de programación en el formato "
            + "deseado a travéz de BERTA, un lenguaje que permite definir plantillas para generar el código. Berta a su vez puede usar archivos "
            + "de Tipos de Datos para sustituir el tipo de dato NINO por el del lenguaje cuyo código se generará. ";

        public static string Theme1 = "1. Estructura del lenguaje NINO";
        public static string Theme1_Text = "&nbsp;&nbsp;&nbsp;NINO es un lenguaje sencillo, basado en SQL el cual es una forma resumida de definir las tablas que "
            + "conforman una base de datos, con sus respectivas llaves primarias, foráneas y campos de identidad lo que permite indicar relaciones "
            + "entre las tablas las cuales le permiten al intérprete de BERTA tomar desiciones usando instrucciones especializadas al generar código."
            + "<br /><br />&nbsp;&nbsp;&nbsp;A continuación puede observarse un ejemplo de una tabla de usuarios del sistema, donde puede verse el lenguaje NINO en su totalidad:";
        public static string Theme1_Example = "SET DB_SERVER AS 127.0.0.1;<br />" +
                                                "SET DB_USER AS user;<br />" +
                                                "SET DB_USER_PASS AS user_pass;<br />" +
                                                "SET DATABASE AS HelloWorld;<br /><br />" +
                                                "TABLE [HWUsuarios](<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IdUsuario INT NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;NombreUsuario VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Nombre VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Apellido1 VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Apellido2 VARCHAR(50) NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Pass VARCHAR(255) NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IdTitulo VARCHAR(10) NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Admin INT NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IDENTITY ON IdUsuario;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;FOREIGN KEY IdTitulo FROM HWTitulos;<br />" + 
                                                "&nbsp;&nbsp;&nbsp;&nbsp;PRIMARY KEY IdUsuario;<br />" +
                                                ")<br />";

        public static string Theme2 = "2. Instrucciones del lenguaje NINO";
        public static string Theme2_Text = "&nbsp;&nbsp;&nbsp;NINO está compuesto por las siguientes instrucciones que permiten modelar la base de datos:<br /><br />";
        public static string Theme2_Instructions = "<b style=\"color: navy;\"><code>SET DB_SERVER AS <i style=\"color: purple;\">NOMBRE</i>;</code></b> - Establece la dirección o nombre del servidor de "
            + "base de datos. Sirve en casos donde se ocupa escribir el nombre del servidor, como en cadenas de conexión.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DB_USER AS <i style=\"color: purple;\">USUARIO</i>;</code></b> - Establece el nombre del usuario de la "
            + "base de datos. Sirve en casos donde se ocupa escribir el nombre del usuario, como en cadenas de conexión.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DB_USER_PASS AS <i style=\"color: purple;\">CONTRASEÑA</i>;</code></b> - Establece la contraseña del usuario de la "
            + "base de datos. Sirve en casos donde se ocupa escribir la contraseña del usuario, como en cadenas de conexión.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DATABASE AS <i style=\"color: purple;\">BASE_DE_DATOS</i>;</code></b> - Establece el nombre de la "
            + "base de datos. Sirve en casos donde se ocupa escribir el nombre de la base de datos, como en cadenas de conexión.<br /><br />"
            + "<b style=\"color: navy;\"><code>TABLE [<i style=\"color: purple;\">TABLA</i>] ( <i style=\"color: purple;\">INSTRUCCIONES_DEFINICIÓN</i> ) </code></b> - Define una tabla de la base de datos "
            + ". Dentro de los paréntesis irán las instrucciones que definen sus campos, llaves primarias, llaves foráneas y campos de identidad. Ésta es la única instrucción que no lleva punto y coma al final.<br /><br />"
            + "<b style=\"color: navy;\"><code><i style=\"color: purple;\">NOMBRE_CAMPO</i> <i style=\"color: purple;\">TIPO_DATO</i> <i style=\"color: purple;\">NULL | NOT NULL</i>;</code></b> - Define un campo de la tabla "
            + ", primero se indica su nombre, luego el tipo de dato el cual puede ser cualquiera, no obstante NINO solo reconoce los tipos de Microsoft SQL Server por ahora. Finalmente se indica si el campo es NULL o no lo es (NOT NULL).<br /><br />"
            + "<b style=\"color: navy;\"><code>IDENTITY ON <i style=\"color: purple;\">CAMPO_IDENTIDAD</i>;</code></b> - Establece el campo de la tabla con ese nombre "
            + "como un campo de identidad.<br /><br />"
            + "<b style=\"color: navy;\"><code>FOREIGN KEY <i style=\"color: purple;\">CAMPO_FORÁNEO</i> FROM <i style=\"color: purple;\">TABLA_FORÁNEA</i>;</code></b> - Indica que el campo de la tabla con ese nombre "
            + "corresponde a una llave foránea de la tabla indicada, la cual debe estar especificada en el código NINO o habrán problemas al leerlo el intérprete.<br /><br />"
            + "<b style=\"color: navy;\"><code>PRIMARY KEY <i style=\"color: purple;\">LLAVE_PRIMARIA</i>;</code></b> - Establece el campo de la tabla con ese nombre "
            + "como la llave primaria.<br /><br />";

        public static string Theme3 = "3. Instrucciones del lenguaje BERTA";
        public static string Theme3_Text = "&nbsp;&nbsp;&nbsp;Con BERTA es posible definir plantillas para generar código en cualquier lenguaje, "
            + "sus instrucciones y su sintaxis puede ser algo compleja, pero tal diseño permite neutralidad con cualquier lenguaje de programación. "
            + "<br /><br />&nbsp;&nbsp;&nbsp;A continuación se detallan las instrucciones disponibles:<br /><br />";
        public static string Theme3_Instructions = "<b style=\"color: red;\"><code>NIVEL 1</code></b><br /><br />Son instrucciones que se interpretan sin ningún ciclo.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Tipos de Datos\\Tipos.dt</i>[@EB]</code></b> - Indica que cargue el archivo 'Tipos.dt' de la carpeta 'Tipos de Datos' "
            + "en el nivel 0 de tipos de datos, para sustituir los tipos de datos NINO con los indicados en ese archivo usando la instrucción de tercer nivel <b style=\"color: maroon;\"><code>@B_DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_2DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Tipos de Datos\\Tipos2.dt</i>[@EB]</code></b> - Indica que cargue el archivo 'Tipos2.dt' de la carpeta 'Tipos de Datos' "
            + "en el nivel 2 de tipos de datos, para sustituir los tipos de datos NINO con los indicados en ese archivo usando la instrucción de tercer nivel <b style=\"color: maroon;\"><code>@B_2DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_3DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Tipos de Datos\\Tipos3.dt</i>[@EB]</code></b> - Indica que cargue el archivo 'Tipos3.dt' de la carpeta 'Tipos de Datos' "
            + "en el nivel 3 de tipos de datos, para sustituir los tipos de datos NINO con los indicados en ese archivo usando la instrucción de tercer nivel <b style=\"color: maroon;\"><code>@B_3DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_4DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Tipos de Datos\\Tipos4.dt</i>[@EB]</code></b> - Indica que cargue el archivo 'Tipos4.dt' de la carpeta 'Tipos de Datos' "
            + "en el nivel 4 de tipos de datos, para sustituir los tipos de datos NINO con los indicados en ese archivo usando la instrucción de tercer nivel <b style=\"color: maroon;\"><code>@B_4DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_5DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Tipos de Datos\\Tipos5.dt</i>[@EB]</code></b> - Indica que cargue el archivo 'Tipos5.dt' de la carpeta 'Tipos de Datos' "
            + "en el nivel 5 de tipos de datos, para sustituir los tipos de datos NINO con los indicados en ese archivo usando la instrucción de tercer nivel <b style=\"color: maroon;\"><code>@B_5DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATABASE</code></b> - Imprime el nombre de la base de datos.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_SERVER</code></b> - Imprime el nombre o dirección del servidor gestor de bases de datos.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_USER</code></b> - Imprime el nombre del usuario de la base de datos.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_USER_PASS</code></b> - Imprime la contraseña del usuario de la base de datos.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_DB<i style=\"color: red;\"> Código para generar </i>@EB_LOOP_DB</code></b> - Establece que el código contenido en su interior se imprimirá por cada tabla presente en la base"
            + " de datos, dentro se ejecutarán las instrucciones de <b style=\"color: red;\"><code>NIVEL 2</code></b><br /><br />"
            + "<b style=\"color: red;\"><code>NIVEL 2</code></b><br /><br />Son instrucciones que se interpretan dentro del código de un ciclo <b style=\"color: maroon;\"><code>@B_LOOP_DB<i style=\"color: red;\"> Código para generar </i>@EB_LOOP_DB</code></b>"
            + " que recorre las tablas de la base de datos.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_TABLENAME</code></b> - Imprime el nombre de la tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código a concatenar</i>[@EB]</code></b><i style=\"color: red;\"> Código para generar </i>@EB_LOOP_TABLE</code></b> - Establece que "
            + "el código contenido en su interior se imprimirá por cada columna presente en la tabla"
            + ", dentro se ejecutarán las instrucciones de <b style=\"color: red;\"><code>NIVEL 3</code></b>. Al final de cada iteración concatenará "
            + "el código para concatenar indicado.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_NON_PRIMARY<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código a concatenar</i>[@EB]</code></b><i style=\"color: red;\"> Código para generar </i>@EB_LOOP_TABLE_NON_PRIMARY</code></b> - Establece " 
            + "que el código contenido en su interior se imprimirá por cada columna presente en la tabla"
            + " pero no se imprimirá cuando la columna es la llave primaria de la tabla, dentro se ejecutarán las instrucciones de <b style=\"color: red;\">"
            + "<code>NIVEL 3</code></b>. Al final de cada iteración concatenará el código para concatenar indicado.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_PRIMARY_OR_ALL<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código a concatenar</i>[@EB]</code></b><i style=\"color: red;\"> Código para generar </i>@EB_LOOP_TABLE_PRIMARY_OR_ALL</code></b> - " 
            + "Establece que el código contenido en su interior se imprimirá solo por cada llave primaria de la tabla"
            + " pero si la tabla no tiene llaves primarias imprimirá por cada columna de la tabla, dentro se ejecutarán las instrucciones de <b style=\"color: red;\"><code>NIVEL 3</code></b>. Al final de cada iteración concatenará el código para concatenar indicado.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_PRIMARY_OR_FIRST<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código a concatenar</i>[@EB]</code></b><i style=\"color: red;\"> Código para generar </i>@EB_LOOP_TABLE_PRIMARY_OR_FIRST</code></b> - Establece que el código contenido en su interior se imprimirá por cada llave primaria de la tabla"
            + " si no hay llaves primarias se imprime solo una vez por la primer columna de la tabla, dentro se ejecutarán las instrucciones de <b style=\"color: red;\"><code>NIVEL 3</code></b>. Al final de cada iteración concatenará el código para concatenar indicado.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_PRIMARY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si tiene llave primaria o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_IDENTITY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si tiene campo de identidad o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_FOREIGN</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si tiene llave foránea o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_FOREIGN_OUT</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si tiene llave foránea en otra tabla o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLES_RELATIONED</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código </i>[@EB]</code></b> - Ciclo que imprime su código interno recorriendo sólo tablas que tengan relación con otras (su nombre aparece en la llave foránea de otra tabla), dentro se ejecutarán "
            + "las instrucciones de <b style=\"color: red;\"><code>NIVEL 3</code></b> y <b style=\"color: red;\"><code>NIVEL 4</code></b> <br /><br />"
            + "<b style=\"color: red;\"><code>NIVEL 3</code></b><br /><br />Son instrucciones que se interpretan dentro del código de un ciclo <b style=\"color: maroon;\"><code>@B_LOOP_TABLE<i style=\"color: red;\"> Código para generar </i>@EB_LOOP_TABLE</code></b>"
            + " o similares que recorren las columnas de una tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b> - Imprime el código de adentro cuando la iteración corresponde a la llave primaria de la tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b> - Imprime el código de adentro cuando la iteración corresponde al campo identidad de la tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b> - Imprime el código de adentro cuando la iteración corresponde a una llave foránea de la tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_ITERATION</code></b> - Imprime el número de iteración del ciclo de columnas en la tabla.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_NULL</code></b> - Representa un valor null, se remueve dejando su espacio en blanco.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_COLNAME</code></b> - Imprime el nombre de la columna.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATALENGTH</code></b> - Imprime la longitud del tipo de dato de la columna.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_NINO_DATATYPE</code></b> - Imprime el tipo de dato NINO de la columna.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATATYPE</code></b> - Imprime el tipo de dato correspondiente en el nivel 0 de memoria de tipos de datos definidos previamente.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_2DATATYPE</code></b> - Imprime el tipo de dato correspondiente en el nivel 2 de memoria de tipos de datos definidos previamente.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_3DATATYPE</code></b> - Imprime el tipo de dato correspondiente en el nivel 3 de memoria de tipos de datos definidos previamente.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_4DATATYPE</code></b> - Imprime el tipo de dato correspondiente en el nivel 4 de memoria de tipos de datos definidos previamente.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_5DATATYPE</code></b> - Imprime el tipo de dato correspondiente en el nivel 5 de memoria de tipos de datos definidos previamente.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_DATALENGTH</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si la columna tiene un valor de longitud de tipo de dato o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_NULL</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si la columna admite valores NULL o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_PRIMARY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si la columna es llave primaria o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_IDENTITY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si la columna es identidad o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_FOREIGN</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Primer código </i> | <i style=\"color: red;\"> Segundo código </i> [@EB]</code></b> - Condición que"
            + " imprime el primer código si la columna es llave foránea o imprime el segundo código en caso contrario.<br /><br />"
            + "<b style=\"color: red;\"><code>NIVEL 4</code></b><br /><br />Son instrucciones que se interpretan dentro del código de un ciclo <b style=\"color: maroon;\"><code>@B_LOOP_TABLES_RELATIONED</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Código </i>[@EB]</code></b><br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_TABLE</code></b> - Imprime el nombre de la tabla de la llave foránea.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_TABLE_COLNAME</code></b> - Imprime el nombre de la columna de llave foránea.<br /><br />"
            + "<b style=\"color: red;\"><code>NIVEL 5</code></b><br /><br />Instrucciones que se interpretan dentro de otras instrucciones específicas<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY</code></b> - Imprime el nombre de la llave primaria de la tabla. Solo dentro de la instrucción "
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b><br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY</code></b> - Imprime el nombre del campo identidad de la tabla. Solo dentro de la instrucción "
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b><br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN</code></b> - Imprime el nombre de la llave foránea de la tabla. Solo dentro de la instrucción "
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Código para generar </i>[@EB]</code></b><br /><br />";

        public static string Theme4 = "4. Uso de  Nino Seisei";
        public static string Theme4_Text = "&nbsp;&nbsp;&nbsp;Lo primero es escribir el código NINO correspondiente a la base de datos. Para facilitar "
            + "esta parte la herramienta puede generar este código conectándose a una base de datos de Microsoft SQL Server, no obstante aún no es capaz "
            + "de leer estructuras de vistas.<br /><br />"
            + "&nbsp;&nbsp;&nbsp;Una vez obtenido el código NINO este debe cargarse en la memoria a través del intérprete, esto se realiza con el botón "
            + "u opción del menú 'Ejecutar Código Nino', este puede tardar varios minutos en completarse."
            + "&nbsp;&nbsp;&nbsp;Finalmente se carga una plantilla BERTA y con el botón u opción del menú 'Generar Código desde Plantilla Berta' se " 
            + "procede a generar el código deseado.";

        public static string Conclusion = "5. Conclusión";
        public static string Conclusion_Text = "&nbsp;&nbsp;&nbsp;Con  Nino Seisei el desarrollador puede generar código que normalmente se " 
            + "tardaría bastante en escribir y que le robaría tiempo que pudo haber invertido en desarrollo de aspectos ingeniosos y creativos, no "
            + "en tareas repetitivas y agotadoras. <br /><br />&nbsp;&nbsp;&nbsp;El desarrollador podrá generar el código que desea en la forma que lo quiere, lo cual le permite " 
            + "tener un amplio control en su proyecto de software, ya que esta herramienta no genera un proyecto entero difícil de mantener sino, lo " 
            + "que el desarrollador desea obtener rápido, sin molestarse en tareas monótonas. <br /><br />"
            + "&nbsp;&nbsp;&nbsp;Aplicación dedicada en memoria de mi abuela Dagoberta Segura Quesada, conocida como Doña Berta y, mi difunto gatito, Nino. <br /><br />";

        public static string Contents =
            "<html> " +
            "   <head> " +
            "       <style type=\"text/css\"> " + 
            "           body{ " + 
            "               font-family: arial, helvetica, sans-serif;" + 
            "           } " + 
            "       </style> " + 
            "   </head> " + 
            "   <body> " + 
            "       <table width=\"100%\"> " + 
            "           <tr> " +
            "               <td width=\"100%\"> " +
            "                   <span style=\"color: indigo; font-size: 12pt; font-weight: bold;\"><br />" + Title + "</span> " +
            "                   <br /> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Intro + "</span> " +
            "                   <p>" + Intro_Text + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme1 + "</span> " +
            "                   <p>" + Theme1_Text + "</p> " +
            "                   <code>" + Theme1_Example + "</code> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme2 + "</span> " +
            "                   <p>" + Theme2_Text + "</p> " +
            "                   <p>" + Theme2_Instructions + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme3 + "</span> " +
            "                   <p>" + Theme3_Text + "</p> " +
            "                   <p>" + Theme3_Instructions + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme4 + "</span> " +
            "                   <p>" + Theme4_Text + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Conclusion + "</span> " +
            "                   <p>" + Conclusion_Text + "</p> " +
            "               </td> " +
            "           </tr> " +
            "       </table> " +
            "   </body> " +
            "</html> ";
    }
}
