﻿/*   Nino Seisei 
 *  ©2012  Antonio Bolaños Arias.
 * 
 *  This program is free software: you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation, either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;

namespace Seisei.Global
{
    public class HelpEnUS
    {
        public static string Title = "Nino Seisei Help Contents";

        public static string Intro = "Introduction";
        public static string Intro_Text = "&nbsp;&nbsp;&nbsp;Nino Seisei is a free tool under GNU GPL v3 license that allows data access code generation, where, "
            + "using NINO language based on SQL, you can generate code in any text based programming language in your desired format using "
            + "BERTA, the template language used to generate the code. BERTA works with 'Data Type Specification' files, that allow to replace the NINO "
            + "datatype for the corresponding datatype in the programming language. ";

        public static string Theme1 = "1. NINO Language Structure";
        public static string Theme1_Text = "&nbsp;&nbsp;&nbsp;NINO is a very simple language, based on SQL to create a very simple and summarized way "
            + "to define the database with their tables, fields and table relations through specifying primary and foreign keys. This allows the BERTA interpreter"
            + " take decisions using it's set of instructions to create code generation templates."
            + "<br /><br />&nbsp;&nbsp;&nbsp;Now you can see an example of a users table defined in NINO, using all the set of instructions available:";
        public static string Theme1_Example = "SET DB_SERVER AS 127.0.0.1;<br />" +
                                                "SET DB_USER AS user;<br />" +
                                                "SET DB_USER_PASS AS user_pass;<br />" +
                                                "SET DATABASE AS HelloWorld;<br /><br />" +
                                                "TABLE [HWUsuarios](<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IdUser INT NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;UserName VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Name VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;LastName VARCHAR(50) NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Pass VARCHAR(255) NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IdTitle VARCHAR(10) NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;Admin INT NOT NULL;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;IDENTITY ON IdUser;<br />" +
                                                "&nbsp;&nbsp;&nbsp;&nbsp;FOREIGN KEY IdTitle FROM HWTitles;<br />" + 
                                                "&nbsp;&nbsp;&nbsp;&nbsp;PRIMARY KEY IdUser;<br />" +
                                                ")<br />";

        public static string Theme2 = "2. NINO Instructions";
        public static string Theme2_Text = "&nbsp;&nbsp;&nbsp;The following instructions allows to define the database:<br /><br />";
        public static string Theme2_Instructions = "<b style=\"color: navy;\"><code>SET DB_SERVER AS <i style=\"color: purple;\">NAME</i>;</code></b> - Set the database server's name or direction"
            + ". Useful if you want to generate code that include database connection strings.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DB_USER AS <i style=\"color: purple;\">USER</i>;</code></b> - Sets the database server user name"
            + ". Useful if you want to generate code that include database connection strings.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DB_USER_PASS AS <i style=\"color: purple;\">PASSWORD</i>;</code></b> - Sets the database server user password"
            + ". Useful if you want to generate code that include database connection strings.<br /><br />"
            + "<b style=\"color: navy;\"><code>SET DATABASE AS <i style=\"color: purple;\">BASE_DE_DATOS</i>;</code></b> - Sets the database name"
            + ". Useful if you want to generate code that include database connection strings.<br /><br />"
            + "<b style=\"color: navy;\"><code>TABLE [<i style=\"color: purple;\">TABLA</i>] ( <i style=\"color: purple;\">DEFINITION_INSTRUCTIONS</i> ) </code></b> - Specify a database table"
            + ". Inside the '( )' you have to define the table's columns with it's primary and foregn keys. This is the only instruction that don't need to end with ';'.<br /><br />"
            + "<b style=\"color: navy;\"><code><i style=\"color: purple;\">COLUMN_NAME</i> <i style=\"color: purple;\">DATA_TYPE</i> <i style=\"color: purple;\">NULL | NOT NULL</i>;</code></b> - Sets a table column "
            + ", first you must indicate the column's name, then the datatype with can be anything, however the NINO reader only manages the Microsoft SQL Server data types. Finally you have to specify if the column can be NULL or not (NOT NULL).<br /><br />"
            + "<b style=\"color: navy;\"><code>IDENTITY ON <i style=\"color: purple;\">IDENTITY_COLUMN</i>;</code></b> - Sets the column with that name as identity.<br /><br />"
            + "<b style=\"color: navy;\"><code>FOREIGN KEY <i style=\"color: purple;\">FOREIGN_KEY_COLUMN</i> FROM <i style=\"color: purple;\">FOREIGN_TABLE</i>;</code></b> - Sets the column with that name as a foreign key "
            + ".<br /><br />"
            + "<b style=\"color: navy;\"><code>PRIMARY KEY <i style=\"color: purple;\">PRIMARY_KEY_COLUMN</i>;</code></b> - Sets the column with that name as a primary key.<br /><br />";

        public static string Theme3 = "3. BERTA Instructions";
        public static string Theme3_Text = "&nbsp;&nbsp;&nbsp;BERTA is used to define code generating templates, whose code can be in any language, "
            + "it's instructions and syntax can be complex, but such design was made with neutrality with any coding language in mind, do BERTA won't conflict with the generated code language. "
            + "<br /><br />&nbsp;&nbsp;&nbsp;These are the instructions you can use to start generating code:<br /><br />";
        public static string Theme3_Instructions = "<b style=\"color: red;\"><code>LEVEL 1</code></b><br /><br />Thse are instructions that aren't within a loop, these are executed first.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Data Types\\Types.dt</i>[@EB]</code></b> - Specify that the interpreter must load 'Types.dt' file from 'Data Types' folder "
            + "in the LEVEL 0 data types memory, to replace NINO datatypes with the ones specifies in the data types file using the LEVEL 3 instruction <b style=\"color: maroon;\"><code>@B_DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_2DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Data Types\\Types2.dt</i>[@EB]</code></b> - Specify that the interpreter must load 'Types2.dt' file from 'Data Types' folder "
            + "in the LEVEL 2 data types memory, to replace NINO datatypes with the ones specifies in the data types file using the LEVEL 3 instruction <b style=\"color: maroon;\"><code>@B_2DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_3DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Data Types\\Types3.dt</i>[@EB]</code></b> - Specify that the interpreter must load 'Types3.dt' file from 'Data Types' folder "
            + "in the LEVEL 3 data types memory, to replace NINO datatypes with the ones specifies in the data types file using the LEVEL 3 instruction <b style=\"color: maroon;\"><code>@B_3DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_4DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Data Types\\Types4.dt</i>[@EB]</code></b> - Specify that the interpreter must load 'Types4.dt' file from 'Data Types' folder "
            + "in the LEVEL 4 data types memory, to replace NINO datatypes with the ones specifies in the data types file using the LEVEL 3 instruction <b style=\"color: maroon;\"><code>@B_4DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_5DEFINE_DATA_TYPES[@B]<i style=\"color: red;\">Data Types\\Types5.dt</i>[@EB]</code></b> - Specify that the interpreter must load 'Types5.dt' file from 'Data Types' folder "
            + "in the LEVEL 5 data types memory, to replace NINO datatypes with the ones specifies in the data types file using the LEVEL 3 instruction <b style=\"color: maroon;\"><code>@B_5DATATYPE</code></b>.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATABASE</code></b> - Prints the database name.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_SERVER</code></b> - Prints the name or direction of the database server.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_USER</code></b> - Prints the database user's name.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DB_USER_PASS</code></b> - Prints the database user's password.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_DB<i style=\"color: red;\"> Code to generate </i>@EB_LOOP_DB</code></b> - Tells the interpreter to print the code inside for each table found in the database"
            + ", inside the code that will be generated will run the <b style=\"color: red;\"><code>LEVEL 2</code></b> instructions<br /><br />"
            + "<b style=\"color: red;\"><code>LEVEL 2</code></b><br /><br />These instructions will only run inside the instruction <b style=\"color: maroon;\"><code>@B_LOOP_DB<i style=\"color: red;\"> Code to generate </i>@EB_LOOP_DB</code></b>"
            + " that makes a code generating loop around the tables in the database.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_TABLENAME</code></b> - Prints the current table name in the loop iteration.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to concat</i>[@EB]</code></b><i style=\"color: red;\"> Code to generate </i>@EB_LOOP_TABLE</code></b> - Sets that the "
            + "code inside will be printed for each column in the table"
            + ", inside will run the <b style=\"color: red;\"><code>LEVEL 3</code></b> instructions. At the end of each iteration it will concat "
            + "the code to concat specified.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_NON_PRIMARY<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to concat</i>[@EB]</code></b><i style=\"color: red;\"> Code to generate </i>@EB_LOOP_TABLE_NON_PRIMARY</code></b> - Sets that the "
            + "code inside will be printed for each column in the table"
            + " but it will not print if the column is a primary key, inside will run the <b style=\"color: red;\"><code>LEVEL 3</code></b> instructions. At the end of each iteration it will concat "
            + "the code to concat specified.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_PRIMARY_OR_ALL<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to concat</i>[@EB]</code></b><i style=\"color: red;\"> Code to generate </i>@EB_LOOP_TABLE_PRIMARY_OR_ALL</code></b> - "
            + "Sets that the code inside will be printed for each column in the table only if the column is a primary key, "
            + "if there aren't any primary keys it will print all fields, inside will run the <b style=\"color: red;\"><code>LEVEL 3</code></b> instructions. At the end of each iteration it will concat "
            + "the code to concat specified.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLE_PRIMARY_OR_FIRST<b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to concat</i>[@EB]</code></b><i style=\"color: red;\"> Code to generate </i>@EB_LOOP_TABLE_PRIMARY_OR_FIRST</code></b> - "
            + "Sets that the code inside will be printed for each column in the table only if the column is a primary key, "
            + "if there aren't any primary keys it will print the first field, inside will run the <b style=\"color: red;\"><code>LEVEL 3</code></b> instructions. At the end of each iteration it will concat "
            + "the code to concat specified.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_PRIMARY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Fisrt code to generate </i> | <i style=\"color: red;\"> Second code to generate </i> [@EB]</code></b> - Condition that"
            + " prints the first code if it have a primary key otherwise, it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_IDENTITY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Fisrt code to generate </i> | <i style=\"color: red;\"> Second code to generate </i> [@EB]</code></b> - Condition that"
            + " prints the first code if it have an identity column otherwise, it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_FOREIGN</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Fisrt code to generate </i> | <i style=\"color: red;\"> Second code to generate </i> [@EB]</code></b> - Condition that"
            + " prints the first code if it have a foreign key otherwise, it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_FOREIGN_OUT</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Fisrt code to generate </i> | <i style=\"color: red;\"> Second code to generate </i> [@EB]</code></b> - Condition that"
            + " prints the first code if it have a column that is foreign key in other table otherwise, it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_LOOP_TABLES_RELATIONED</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to generate </i>[@EB]</code></b> - Loop that prints it's internal code only if the table is relationed with another table (when it's name appear in the foreign key of other table in the NINO code), inside will run "
            + "<b style=\"color: red;\"><code>LEVEL 3</code></b> and <b style=\"color: red;\"><code>LEVEL 4</code></b> instructions.<br /><br />"
            + "<b style=\"color: red;\"><code>LEVEL 3</code></b><br /><br />These instructions run inside loops around table columns like the one made by the <b style=\"color: maroon;\"><code>@B_LOOP_TABLE<i style=\"color: red;\"> Code to generate </i>@EB_LOOP_TABLE</code></b>"
            + " instruction.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> - Prints it's inside code when the current iteration is on a primary key column.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> - Prints it's inside code when the current iteration is on a identity column.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> - Prints it's inside code when the current iteration is on a foreign key column.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_ITERATION</code></b> - Prints the loop's current iteration number.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_NULL</code></b> - Equals to a null value, it's just erased leaving nothing behind. Useful in instructions where you don't want to concat code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_COLNAME</code></b> - Prints the column's name.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATALENGTH</code></b> - Prints the column data type length.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_NINO_DATATYPE</code></b> - Prints the column's NINO data type.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_DATATYPE</code></b> - Prints the column's corresponding LEVEL 0 memory data type previously defined.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_2DATATYPE</code></b> - Prints the column's corresponding LEVEL 2 memory data type previously defined.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_3DATATYPE</code></b> - Prints the column's corresponding LEVEL 3 memory data type previously defined.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_4DATATYPE</code></b> - Prints the column's corresponding LEVEL 4 memory data type previously defined.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_5DATATYPE</code></b> - Prints the column's corresponding LEVEL 5 memory data type previously defined.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_HAVE_DATALENGTH</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " First code </i> | <i style=\"color: red;\"> Second code </i> [@EB]</code></b> - Condition that"
            + " prints the first code if the column datatype have length otherwise it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_NULL</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " First code </i> | <i style=\"color: red;\"> Second code </i> [@EB]</code></b> - Condition that"
            + " prints the first code if the column allows NULL values otherwise it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_PRIMARY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " First code </i> | <i style=\"color: red;\"> Second code </i> [@EB]</code></b> - Condition that"
            + " prints the first code if the column have a primary key otherwise it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_IDENTITY</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " First code </i> | <i style=\"color: red;\"> Second code </i> [@EB]</code></b> - Condition that"
            + " prints the first code if the column have an identity otherwise it will print the second code.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IS_FOREIGN</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " First code </i> | <i style=\"color: red;\"> Second code </i> [@EB]</code></b> - Condition that"
            + " prints the first code if the column have a foreign key otherwise it will print the second code.<br /><br />"
            + "<b style=\"color: red;\"><code>LEVEL 4</code></b><br /><br />These instructions will run only inside this instruction's loop <b style=\"color: maroon;\"><code>@B_LOOP_TABLES_RELATIONED</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\">"
            + " Code to generate </i>[@EB]</code></b><br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_TABLE</code></b> - Prints the foreign key's table name.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_TABLE_COLNAME</code></b> - Prints the foreign key's column's name.<br /><br />"
            + "<b style=\"color: red;\"><code>LEVEL 5</code></b><br /><br />Thse only run inside specific instructions<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY</code></b> - Prints the primary key's column name. Only run inside the "
            + "<b style=\"color: maroon;\"><code>@B_PRIMARY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> instruction.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY</code></b> - Prints the identity column name. Only run inside the "
            + "<b style=\"color: maroon;\"><code>@B_IDENTITY_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> instruction.<br /><br />"
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN</code></b> - Prints the foreign key's column name. Only run inside the "
            + "<b style=\"color: maroon;\"><code>@B_FOREIGN_CODE</code></b><b style=\"color: teal;\"><code>[@B]<i style=\"color: red;\"> Code to generate </i>[@EB]</code></b> instruction.<br /><br />";

        public static string Theme4 = "4. Nino Seisei Usage";
        public static string Theme4_Text = "&nbsp;&nbsp;&nbsp;The first step is to write the corresponding NINO code of your database. To ease this task "
            + "Nino Seisei can connect to a Microsoft SQL Server database and generate the NINO code form it's structure, however it can't read "
            + "views structures.<br /><br />"
            + "&nbsp;&nbsp;&nbsp;Once you have the NINO code you must load it into memory using the NINO reader, this can be done with the button or "
            + "menú option called 'Run Nino Code', this can take some minutes to complete."
            + "&nbsp;&nbsp;&nbsp;Then you must open a BERTA template created before and using the 'Generate Code from Berta Template' button or " 
            + "menu option you will get your generated code, ready to use.";

        public static string Conclusion = "5. Conclusion";
        public static string Conclusion_Text = "&nbsp;&nbsp;&nbsp;With Nino Seisei the developer can generate code that normally would take lots of time " 
            + "writing, taking away time that should have been invested in developing ingenious and creative aspects of the software project that is working on, "
            + "instead of doind tiring, boring repetitive tasks. <br /><br />&nbsp;&nbsp;&nbsp;The developer can generate the code in the format and way desired " 
            + " so, this allows greater control of the software project, because this tool doesn't generate entire, hard to understand and mantain projects, only " 
            + "generates what the developer wants fast, without the hassle of monotonous tasks. <br /><br />"
            + "&nbsp;&nbsp;&nbsp;Dedicated in the memory of my grandmother Dagoberta Segura Quesada, known as Doña Berta and, my defunct cat, Nino. <br /><br />";

        public static string Contents =
            "<html> " +
            "   <head> " +
            "       <style type=\"text/css\"> " + 
            "           body{ " + 
            "               font-family: arial, helvetica, sans-serif;" + 
            "           } " + 
            "       </style> " + 
            "   </head> " + 
            "   <body> " + 
            "       <table width=\"100%\"> " + 
            "           <tr> " +
            "               <td width=\"100%\"> " +
            "                   <span style=\"color: indigo; font-size: 12pt; font-weight: bold;\"><br />" + Title + "</span> " +
            "                   <br /> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Intro + "</span> " +
            "                   <p>" + Intro_Text + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme1 + "</span> " +
            "                   <p>" + Theme1_Text + "</p> " +
            "                   <code>" + Theme1_Example + "</code> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme2 + "</span> " +
            "                   <p>" + Theme2_Text + "</p> " +
            "                   <p>" + Theme2_Instructions + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme3 + "</span> " +
            "                   <p>" + Theme3_Text + "</p> " +
            "                   <p>" + Theme3_Instructions + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Theme4 + "</span> " +
            "                   <p>" + Theme4_Text + "</p> " +
            "                   <span style=\"color: purple; font-size: 11pt; font-weight: bold;\"><br />" + Conclusion + "</span> " +
            "                   <p>" + Conclusion_Text + "</p> " +
            "               </td> " +
            "           </tr> " +
            "       </table> " +
            "   </body> " +
            "</html> ";
    }
}
